-- count of items shipped each day after D
PREPARE SCIDX_Q1 (date) AS 
    SELECT l_shipdate, COUNT (*)
    FROM scidx_l_shipdate
    WHERE l_shipdate > $1
    GROUP BY l_shipdate;

-- count of items shipped for each supplier on day D
PREPARE SCIDX_Q2 (date) AS
    SELECT l_suppkey, COUNT (*)
    FROM scidx_l_suppkey, scidx_l_shipdate
    WHERE l_shipdate = $1
    AND scidx_l_suppkey.l_orderkey = scidx_l_shipdate.l_orderkey
    AND scidx_l_suppkey.l_linenumber = scidx_l_shipdate.l_linenumber
    GROUP BY l_suppkey;
    
-- count of items shipped for each supplier after day D
PREPARE SCIDX_Q3 (date) AS
    SELECT l_suppkey, COUNT (*)
    FROM scidx_l_suppkey, scidx_l_shipdate
    WHERE l_shipdate > $1
    AND scidx_l_suppkey.l_orderkey = scidx_l_shipdate.l_orderkey
    AND scidx_l_suppkey.l_linenumber = scidx_l_shipdate.l_linenumber
    GROUP BY l_suppkey;
    
-- latest shipdate of all items ordered after each day D    
PREPARE SCIDX_Q4 (date) AS
    SELECT o_orderdate, MAX (l_shipdate)
    FROM scidx_o_orderdate, scidx_l_shipdate
    WHERE l_orderkey = o_orderkey AND o_orderdate > $1
    GROUP BY o_orderdate;

-- for each supplier, latest shipdate of an item from an order that was made on day D
PREPARE SCIDX_Q5 (date) AS
    SELECT l_suppkey, MAX (l_shipdate)
    FROM scidx_o_orderdate, scidx_l_suppkey, scidx_l_shipdate
    WHERE scidx_l_suppkey.l_orderkey = o_orderkey AND o_orderdate = $1
    AND scidx_l_suppkey.l_orderkey = scidx_l_shipdate.l_orderkey
    AND scidx_l_suppkey.l_linenumber = scidx_l_shipdate.l_linenumber
    GROUP BY l_suppkey;
    
-- for each supplier, latest ship date of an item from an order that was made after day D
PREPARE SCIDX_Q6 (date) AS
    SELECT l_suppkey, MAX (l_shipdate)
    FROM scidx_o_orderdate, scidx_l_suppkey, scidx_l_shipdate
    WHERE scidx_l_suppkey.l_orderkey=o_orderkey AND o_orderdate > $1
    AND scidx_l_suppkey.l_orderkey = scidx_l_shipdate.l_orderkey
    AND scidx_l_suppkey.l_linenumber = scidx_l_shipdate.l_linenumber
    GROUP BY l_suppkey;

    
-- Nations for customers (along with lost revenue) for parts that they returned
PREPARE SCIDX_Q7 AS
    SELECT c_nationkey, SUM(l_extendedprice)
    FROM scidx_c_nationkey, scidx_l_extendedprice, scidx_l_returnflag, scidx_o_custkey
    WHERE scidx_l_extendedprice.l_orderkey = o_orderkey 
    AND o_custkey = c_custkey AND l_returnflag='R'
    AND scidx_l_extendedprice.l_orderkey = scidx_l_returnflag.l_orderkey
    AND scidx_l_extendedprice.l_linenumber = scidx_l_returnflag.l_linenumber
    GROUP BY c_nationkey;
