-- count of items shipped each day after D
PREPARE SC_Q1 (date) AS 
    SELECT l_shipdate, COUNT (*)
    FROM sc_l_shipdate
    WHERE l_shipdate > $1
    GROUP BY l_shipdate;

-- count of items shipped for each supplier on day D
PREPARE SC_Q2 (date) AS
    SELECT l_suppkey, COUNT (*)
    FROM sc_l_suppkey, sc_l_shipdate
    WHERE l_shipdate = $1
    AND sc_l_suppkey.l_orderkey = sc_l_shipdate.l_orderkey
    AND sc_l_suppkey.l_linenumber = sc_l_shipdate.l_linenumber
    GROUP BY l_suppkey;
    
-- count of items shipped for each supplier after day D
PREPARE SC_Q3 (date) AS
    SELECT l_suppkey, COUNT (*)
    FROM sc_l_suppkey, sc_l_shipdate
    WHERE l_shipdate > $1
    AND sc_l_suppkey.l_orderkey = sc_l_shipdate.l_orderkey
    AND sc_l_suppkey.l_linenumber = sc_l_shipdate.l_linenumber
    GROUP BY l_suppkey;
    
-- latest shipdate of all items ordered after each day D    
PREPARE SC_Q4 (date) AS
    SELECT o_orderdate, MAX (l_shipdate)
    FROM sc_o_orderdate, sc_l_shipdate
    WHERE l_orderkey = o_orderkey AND o_orderdate > $1
    GROUP BY o_orderdate;

-- for each supplier, latest shipdate of an item from an order that was made on day D
PREPARE SC_Q5 (date) AS
    SELECT l_suppkey, MAX (l_shipdate)
    FROM sc_o_orderdate, sc_l_suppkey, sc_l_shipdate
    WHERE sc_l_suppkey.l_orderkey = o_orderkey AND o_orderdate = $1
    AND sc_l_suppkey.l_orderkey = sc_l_shipdate.l_orderkey
    AND sc_l_suppkey.l_linenumber = sc_l_shipdate.l_linenumber
    GROUP BY l_suppkey;
    
-- for each supplier, latest ship date of an item from an order that was made after day D
PREPARE SC_Q6 (date) AS
    SELECT l_suppkey, MAX (l_shipdate)
    FROM sc_o_orderdate, sc_l_suppkey, sc_l_shipdate
    WHERE sc_l_suppkey.l_orderkey=o_orderkey AND o_orderdate > $1
    AND sc_l_suppkey.l_orderkey = sc_l_shipdate.l_orderkey
    AND sc_l_suppkey.l_linenumber = sc_l_shipdate.l_linenumber
    GROUP BY l_suppkey;

    
-- Nations for customers (along with lost revenue) for parts that they returned
PREPARE SC_Q7 AS
    SELECT c_nationkey, SUM(l_extendedprice)
    FROM sc_c_nationkey, sc_l_extendedprice, sc_l_returnflag, sc_o_custkey
    WHERE sc_l_extendedprice.l_orderkey = o_orderkey 
    AND o_custkey = c_custkey AND l_returnflag='R'
    AND sc_l_extendedprice.l_orderkey = sc_l_returnflag.l_orderkey
    AND sc_l_extendedprice.l_linenumber = sc_l_returnflag.l_linenumber
    GROUP BY c_nationkey;
